==> hoteldruid-mod-nl_2.2.1-1.zip: nl/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Datum is verkeerd"; break;
case "persone":  				$messaggio = "personen"; break;
case "La settimana dal":  			$messaggio = "De week van"; break;
case "Il giorno dal":  				$messaggio = "De dag van"; break;
case "al":  					$messaggio = "naar"; break;
case "è piena":  				$messaggio = "is vol"; break;
case "è pieno":  				$messaggio = "is vol"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Er is</b> nog beschikbaarheid in de gevraagde periode"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Er is geen</b> beschikbaarheid meer in de gevraagde periode"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "De reservering kon worden ingevoegd verdeeld in"; break;
case "parti":  					$messaggio = "delen"; break;
case "Periodo di":  				$messaggio = "Periode van"; break;
case "dal":  					$messaggio = "vanaf"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "Tariffa":  				$messaggio = "Tarief"; break;
case "compresi":  				$messaggio = "inclusief"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "van vaste extra kosten"; break;
case "Ricontrolla":  				$messaggio = "Controleer nog een keer"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar het hoofdmenu"; break;
case "con la tariffa":  			$messaggio = "met tarief"; break;
case "Inserisci la prenotazione":  		$messaggio = "Voeg de reservering in"; break;
case "giorno":  				$messaggio = "dag"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Er zijn geen periodes in teowijzingsregel 1 waarin toegestaan is te reserveren voor gebruiker"; break;
case "costo aggiuntivo unico":  		$messaggio = "single extra kosten"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "wekelijkse extra kosten"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "dagelijkse extra kosten"; break;
case "nº di settimane da applicare":  		$messaggio = "nº weken om toe te wijzen"; break;
case "nº di giorni da applicare":  		$messaggio = "nº dagen om toe te wijzen"; break;
case "di costi aggiuntivi":  			$messaggio = "van extra kosten"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "da moltiplicare per":  			$messaggio = "vermenigvuldigen met"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Het was niet mogelijk om een of meer kosten toe te voegen aan het tarief"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Kies de weken waaraan de extra kosten owrden toegevoegdt"; break;
case "Continua":  				$messaggio = "Ge verder"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Grafisch beschikbaarheids overzicht"; break;
case "potrebbe non essere preciso":  		$messaggio = "is mogelijk niet nauwkeurig"; break;
case "persona":  				$messaggio = "persoon"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "per":  					$messaggio = "for"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", but some movements will have to be made in periods of <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "settimana":  				$messaggio = "week"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Datum is verkeerd"; break;
case "persone":  				$messaggio = "personen"; break;
case "La settimana dal":  			$messaggio = "De week van"; break;
case "Il giorno dal":  				$messaggio = "De dag van"; break;
case "al":  					$messaggio = "naar"; break;
case "è piena":  				$messaggio = "is vol"; break;
case "è pieno":  				$messaggio = "is vol"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Er is</b> nog beschikbaarheid in de gevraagde periode"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Er is geen</b> beschikbaarheid meer in de gevraagde periode"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "De reservering kon worden ingevoegd verdeeld in"; break;
case "parti":  					$messaggio = "delen"; break;
case "Periodo di":  				$messaggio = "Periode van"; break;
case "dal":  					$messaggio = "vanaf"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "Tariffa":  				$messaggio = "Tarief"; break;
case "compresi":  				$messaggio = "inclusief"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "van vaste extra kosten"; break;
case "Ricontrolla":  				$messaggio = "Controleer nog een keer"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar het hoofdmenu"; break;
case "con la tariffa":  			$messaggio = "met tarief"; break;
case "Inserisci la prenotazione":  		$messaggio = "Voeg de reservering in"; break;
case "giorno":  				$messaggio = "dag"; break;
case "TOTALE":  				$messaggio = "TOTAAL"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Er zijn geen periodes in teowijzingsregel 1 waarin toegestaan is te reserveren voor gebruiker"; break;
case "costo aggiuntivo unico":  		$messaggio = "single extra kosten"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "wekelijkse extra kosten"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "dagelijkse extra kosten"; break;
case "nº di settimane da applicare":  		$messaggio = "nº weken om toe te wijzen"; break;
case "nº di giorni da applicare":  		$messaggio = "nº dagen om toe te wijzen"; break;
case "di costi aggiuntivi":  			$messaggio = "van extra kosten"; break;
case "Aggiungi":  				$messaggio = "Voeg toe"; break;
case "da moltiplicare per":  			$messaggio = "vermenigvuldigen met"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Het was niet mogelijk om een of meer kosten toe te voegen aan het tarief"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Kies de weken waaraan de extra kosten owrden toegevoegdt"; break;
case "Continua":  				$messaggio = "Ge verder"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Grafisch beschikbaarheids overzicht"; break;
case "potrebbe non essere preciso":  		$messaggio = "is mogelijk niet nauwkeurig"; break;
case "persona":  				$messaggio = "persoon"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "per":  					$messaggio = "for"; break;
case "Disponibilità":  				$messaggio = "Availability"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", but some movements will have to be made in periods of <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "settimana":  				$messaggio = "week"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "non disponibile":  			$messaggio = "not available"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
